@@ -104,7 +104,7 @@ class Selenium(Scraper):
             if is_error is False: return None
             else: raise ex
 
-    def on_exists(self, path, element, timeout=0, is_error: bool=True):
+    def on_exists(self, path, element, timeout=0, is_error: bool=False):
         element = self.driver if element is None else element
 
         if timeout > 0:
